define(
//begin v1.x content
{
	"dateFormatItem-yMMMM": "MMMM y",
	"field-thu-narrow-relative+0": "יום ה׳",
	"field-thu-narrow-relative+1": "יום ה׳ הבא",
	"field-sun-narrow-relative+0": "יום א׳",
	"field-sun-narrow-relative+1": "יום א׳ הבא",
	"months-format-wide": [
		"ינואר",
		"פברואר",
		"מרץ",
		"אפריל",
		"מאי",
		"יוני",
		"יולי",
		"אוגוסט",
		"ספטמבר",
		"אוקטובר",
		"נובמבר",
		"דצמבר"
	],
	"dayPeriods-standAlone-abbr-pm": "PM",
	"dateFormatItem-Hms": "H:mm:ss",
	"field-fri-narrow-relative+0": "יום ו׳",
	"field-fri-narrow-relative+1": "יום ו׳ הבא",
	"eraNarrow": [
		"לפנה״ס",
		"לספירה"
	],
	"dateFormatItem-Hmv": "HH:mm v",
	"dateFormatItem-hmsv": "h:mm:ss a v",
	"dateFormatItem-yMMMd": "d בMMM y",
	"dayPeriods-format-abbr-night1": "לילה",
	"dayPeriods-format-abbr-night2": "לפנות בוקר",
	"dayPeriods-format-narrow-evening1": "בערב",
	"days-standAlone-narrow": [
		"א׳",
		"ב׳",
		"ג׳",
		"ד׳",
		"ה׳",
		"ו׳",
		"ש׳"
	],
	"days-standAlone-wide": [
		"יום ראשון",
		"יום שני",
		"יום שלישי",
		"יום רביעי",
		"יום חמישי",
		"יום שישי",
		"יום שבת"
	],
	"dayPeriods-format-abbr-afternoon1": "צהריים",
	"dayPeriods-format-wide-evening1": "בערב",
	"dayPeriods-format-abbr-afternoon2": "אחר הצהריים",
	"dateFormatItem-Ehm": "E h:mm a",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-wed-narrow-relative+-1": "יום ד׳ שעבר",
	"dayPeriods-standAlone-wide-evening1": "ערב",
	"days-format-wide": [
		"יום ראשון",
		"יום שני",
		"יום שלישי",
		"יום רביעי",
		"יום חמישי",
		"יום שישי",
		"יום שבת"
	],
	"dateFormatItem-yMM": "M.y",
	"field-month-short-relative+0": "החודש",
	"field-month-short-relative+1": "החודש הבא",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"dayPeriods-standAlone-narrow-evening1": "ערב",
	"dayPeriods-standAlone-abbr-afternoon1": "צהריים",
	"dayPeriods-standAlone-abbr-afternoon2": "אחה״צ",
	"field-thu-relative+0": "יום חמישי",
	"dayPeriods-standAlone-abbr-night1": "לילה",
	"field-thu-relative+1": "יום חמישי הבא",
	"dayPeriods-standAlone-abbr-night2": "לפנות בוקר",
	"dayPeriods-format-wide-am": "לפנה״צ",
	"field-fri-relative+0": "יום שישי",
	"field-fri-relative+1": "יום שישי הבא",
	"dateFormatItem-yMd": "d.M.y",
	"field-thu-narrow-relative+-1": "יום ה׳ שעבר",
	"field-quarter-relative+0": "רבעון זה",
	"field-quarter-relative+1": "הרבעון הבא",
	"field-sun-short-relative+0": "יום א׳",
	"timeFormat-short": "H:mm",
	"field-sun-short-relative+1": "יום א׳ הבא",
	"dateFormatItem-hms": "h:mm:ss a",
	"dayPeriods-format-narrow-afternoon1": "בצהריים",
	"dateFormatItem-Md": "d.M",
	"dayPeriods-format-narrow-afternoon2": "אחה״צ",
	"dateFormatItem-Hmsv": "HH:mm:ss v",
	"dateFormatItem-hmv": "h:mm a v",
	"field-week-narrow": "שב׳",
	"field-hour-relative+0": "בשעה זו",
	"field-day-relative+-1": "אתמול",
	"field-day-relative+-2": "שלשום",
	"field-mon-narrow-relative+-1": "יום ב׳ שעבר",
	"field-minute-narrow": "דק׳",
	"field-thu-short-relative+0": "יום ה׳",
	"field-mon-relative+0": "יום שני",
	"field-thu-short-relative+1": "יום ה׳ הבא",
	"field-mon-relative+1": "יום שני הבא",
	"field-day-narrow-relative+0": "היום",
	"field-era-short": "תקופה",
	"field-day-narrow-relative+1": "מחר",
	"field-sat-narrow-relative+0": "שבת",
	"timeFormat-long": "H:mm:ss z",
	"field-sat-narrow-relative+1": "שבת הבאה",
	"field-week-narrow-relative+0": "השבוע",
	"field-week-narrow-relative+1": "השבוע הבא",
	"field-wed-narrow-relative+0": "יום ד׳",
	"field-wed-narrow-relative+1": "יום ד׳ הבא",
	"field-month": "חודש",
	"months-standAlone-wide": [
		"ינואר",
		"פברואר",
		"מרץ",
		"אפריל",
		"מאי",
		"יוני",
		"יולי",
		"אוגוסט",
		"ספטמבר",
		"אוקטובר",
		"נובמבר",
		"דצמבר"
	],
	"field-weekday-narrow": "יום בשבוע",
	"dayPeriods-standAlone-narrow-afternoon1": "צהריים",
	"dayPeriods-standAlone-narrow-afternoon2": "אחה״צ",
	"field-year-relative+0": "השנה",
	"field-year-relative+1": "השנה הבאה",
	"dayPeriods-format-abbr-evening1": "ערב",
	"dayPeriods-format-narrow-midnight": "חצות",
	"dayPeriods-format-wide-midnight": "חצות",
	"field-tue-relative+0": "יום שלישי",
	"field-tue-relative+1": "יום שלישי הבא",
	"dayPeriods-standAlone-abbr-evening1": "ערב",
	"dateFormatItem-hm": "h:mm a",
	"dayPeriods-standAlone-wide-midnight": "חצות",
	"field-year-narrow": "שנ׳",
	"field-tue-short-relative+0": "יום ג׳",
	"dayPeriods-standAlone-narrow-midnight": "חצות",
	"field-tue-short-relative+1": "יום ג׳ הבא",
	"field-tue-narrow-relative+0": "יום ג׳",
	"field-tue-narrow-relative+1": "יום ג׳ הבא",
	"dateTimeFormat-full": "{1} בשעה {0}",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-EBhm": "E h:mm B",
	"dateFormatItem-H": "H",
	"field-wed-relative+0": "יום רביעי",
	"field-wed-relative+1": "יום רביעי הבא",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+0": "יום ד׳",
	"field-fri-short-relative+0": "יום ו׳",
	"field-wed-short-relative+1": "יום ד׳ הבא",
	"field-fri-short-relative+1": "יום ו׳ הבא",
	"field-weekOfMonth-short": "השבוע בחודש",
	"field-quarter-short-relative+-1": "הרבעון הקודם",
	"field-year-short-relative+-1": "השנה שעברה",
	"dateFormatItem-Bhm": "h:mm B",
	"dayPeriods-format-wide-night1": "בלילה",
	"dayPeriods-format-wide-night2": "לפנות בוקר",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-quarter-narrow-relative+-1": "הרבעון הקודם",
	"dateFormatItem-d": "d",
	"dayPeriods-format-abbr-pm": "אחה״צ",
	"dateFormatItem-h": "‏h a",
	"quarters-standAlone-wide": [
		"רבעון 1",
		"רבעון 2",
		"רבעון 3",
		"רבעון 4"
	],
	"field-weekOfMonth-narrow": "השבוע בחודש",
	"dateFormatItem-y": "y",
	"field-minute-relative+0": "בדקה זו",
	"field-year-short-relative+0": "השנה",
	"dateFormatItem-EBhms": "E h:mm:ss B",
	"field-year-short-relative+1": "השנה הבאה",
	"field-weekday": "יום בשבוע",
	"dayPeriods-format-narrow-pm": "אחה״צ",
	"field-tue-narrow-relative+-1": "יום ג׳ שעבר",
	"dateFormatItem-yMEd": "E, d.M.y",
	"dayPeriods-standAlone-wide-night1": "לילה",
	"dayPeriods-standAlone-wide-night2": "לפנות בוקר",
	"field-year-narrow-relative+-1": "השנה שעברה",
	"field-sat-relative+-1": "יום שבת שעבר",
	"dayPeriods-format-abbr-midnight": "חצות",
	"dayPeriods-format-narrow-morning1": "בבוקר",
	"dayPeriods-format-wide-morning1": "בבוקר",
	"dayPeriods-standAlone-abbr-midnight": "חצות",
	"dayPeriods-standAlone-narrow-pm": "אחה״צ",
	"dayPeriods-standAlone-wide-morning1": "בוקר",
	"field-mon-narrow-relative+0": "יום ב׳",
	"field-mon-narrow-relative+1": "יום ב׳ הבא",
	"field-second": "שנייה",
	"dateFormatItem-yMMMEd": "E, d בMMM y",
	"field-year-relative+-1": "השנה שעברה",
	"field-weekdayOfMonth-short": "יום בחודש",
	"dateFormat-short": "d.M.y",
	"eraNames": [
		"לפני הספירה",
		"לספירה"
	],
	"field-second-short": "שנ׳",
	"field-thu-short-relative+-1": "יום ה׳ שעבר",
	"field-zone": "אזור זמן",
	"field-dayperiod-narrow": "AM/PM",
	"field-sun-short-relative+-1": "יום א׳ שעבר",
	"dayPeriods-standAlone-narrow-morning1": "בוקר",
	"eraAbbr": [
		"לפנה״ס",
		"לספירה"
	],
	"field-week-short": "שב׳",
	"dayPeriods-standAlone-abbr-am": "AM",
	"dayPeriods-standAlone-wide-pm": "PM",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+0": "היום",
	"field-day-relative+1": "מחר",
	"field-day-relative+2": "מחרתיים",
	"field-day-short-relative+0": "היום",
	"field-dayOfYear-short": "יום בשנה",
	"field-day-short-relative+1": "מחר",
	"dateFormat-long": "d בMMMM y",
	"field-day-short-relative+2": "מחרתיים",
	"field-sun-narrow-relative+-1": "יום א׳ שעבר",
	"field-second-relative+0": "עכשיו",
	"field-quarter-relative+-1": "הרבעון הקודם",
	"dayPeriods-format-narrow-night1": "בלילה",
	"dayPeriods-format-narrow-night2": "לפנות בוקר",
	"quarters-format-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"dayPeriods-standAlone-narrow-night1": "לילה",
	"dayPeriods-standAlone-narrow-night2": "לפנות בוקר",
	"field-week-relative+-1": "השבוע שעבר",
	"dayPeriods-format-abbr-morning1": "בוקר",
	"field-month-relative+-1": "החודש שעבר",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-year": "שנה",
	"field-era": "תקופה",
	"dayPeriods-standAlone-abbr-morning1": "בוקר",
	"days-standAlone-short": [
		"א׳",
		"ב׳",
		"ג׳",
		"ד׳",
		"ה׳",
		"ו׳",
		"ש׳"
	],
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"dateFormatItem-yQQQQ": "QQQQ y",
	"field-day-short-relative+-1": "אתמול",
	"field-day-short-relative+-2": "שלשום",
	"dateFormatItem-GyMMM": "MMM y G",
	"timeFormat-full": "H:mm:ss zzzz",
	"dateFormatItem-Bhms": "h:mm:ss B",
	"field-hour": "שעה",
	"field-dayOfYear-narrow": "יום בשנה",
	"field-quarter": "רבעון",
	"field-month-narrow-relative+0": "החודש",
	"field-month-narrow-relative+1": "החודש הבא",
	"field-day": "יום",
	"field-mon-relative+-1": "יום שני שעבר",
	"field-dayOfYear": "יום בשנה",
	"dateFormat-medium": "d בMMM y",
	"dateTimeFormat-short": "{1}, {0}",
	"dateFormatItem-yMMM": "MMM y",
	"dateFormatItem-GyMMMd": "d בMMM y G",
	"dateFormatItem-MEd": "E, d.M",
	"field-tue-short-relative+-1": "יום ג׳ שעבר",
	"field-year-short": "שנ׳",
	"field-month-short": "חו׳",
	"dateFormatItem-MMMEd": "E, d בMMM",
	"dayPeriods-format-wide-afternoon1": "בצהריים",
	"dateFormatItem-MMMd": "d בMMM",
	"dayPeriods-format-wide-afternoon2": "אחר הצהריים",
	"dateFormatItem-Bh": "h B",
	"months-format-abbr": [
		"ינו׳",
		"פבר׳",
		"מרץ",
		"אפר׳",
		"מאי",
		"יוני",
		"יולי",
		"אוג׳",
		"ספט׳",
		"אוק׳",
		"נוב׳",
		"דצמ׳"
	],
	"dayPeriods-format-abbr-am": "לפנה״צ",
	"field-sat-relative+0": "יום שבת",
	"field-sat-relative+1": "יום שבת הבא",
	"dayPeriods-format-wide-pm": "אחה״צ",
	"field-zone-short": "אזור",
	"days-standAlone-abbr": [
		"יום א׳",
		"יום ב׳",
		"יום ג׳",
		"יום ד׳",
		"יום ה׳",
		"יום ו׳",
		"שבת"
	],
	"field-week-short-relative+0": "השבוע",
	"field-week-short-relative+1": "השבוע הבא",
	"dayPeriods-standAlone-wide-afternoon1": "צהריים",
	"dayPeriods-standAlone-wide-afternoon2": "אחר הצהריים",
	"field-fri-short-relative+-1": "יום ו׳ שעבר",
	"field-month-narrow": "חו׳",
	"dayPeriods-format-narrow-am": "לפנה״צ",
	"field-month-narrow-relative+-1": "החודש שעבר",
	"days-format-abbr": [
		"יום א׳",
		"יום ב׳",
		"יום ג׳",
		"יום ד׳",
		"יום ה׳",
		"יום ו׳",
		"שבת"
	],
	"field-weekday-short": "יום בשבוע",
	"field-day-narrow-relative+-1": "אתמול",
	"field-day-narrow-relative+-2": "שלשום",
	"field-quarter-short": "רבע׳",
	"days-format-short": [
		"א׳",
		"ב׳",
		"ג׳",
		"ד׳",
		"ה׳",
		"ו׳",
		"ש׳"
	],
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"days-format-narrow": [
		"א׳",
		"ב׳",
		"ג׳",
		"ד׳",
		"ה׳",
		"ו׳",
		"ש׳"
	],
	"dateFormatItem-EHm": "E H:mm",
	"field-quarter-narrow": "רבע׳",
	"field-mon-short-relative+0": "יום ב׳",
	"field-mon-short-relative+1": "יום ב׳ הבא",
	"field-dayperiod-short": "AM/PM",
	"dayPeriods-standAlone-narrow-am": "לפנה״צ",
	"field-week-narrow-relative+-1": "השבוע שעבר",
	"field-thu-relative+-1": "יום חמישי שעבר",
	"field-fri-narrow-relative+-1": "יום ו׳ שעבר",
	"field-mon-short-relative+-1": "יום ב׳ שעבר",
	"timeFormat-medium": "H:mm:ss",
	"field-quarter-short-relative+0": "רבעון זה",
	"field-quarter-short-relative+1": "הרבעון הבא",
	"dateFormatItem-Ed": "E ה-d",
	"field-wed-relative+-1": "יום רביעי שעבר",
	"field-weekOfMonth": "השבוע בחודש",
	"field-weekdayOfMonth-narrow": "יום בחודש",
	"dayPeriods-standAlone-wide-am": "AM",
	"dateFormatItem-yQQQ": "QQQ y",
	"field-fri-relative+-1": "יום שישי שעבר",
	"field-minute": "דקה",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"quarters-format-wide": [
		"רבעון 1",
		"רבעון 2",
		"רבעון 3",
		"רבעון 4"
	],
	"field-day-short": "יום",
	"field-dayperiod": "לפנה״צ/אחה״צ",
	"field-hour-short": "שעה",
	"months-standAlone-abbr": [
		"ינו׳",
		"פבר׳",
		"מרץ",
		"אפר׳",
		"מאי",
		"יוני",
		"יולי",
		"אוג׳",
		"ספט׳",
		"אוק׳",
		"נוב׳",
		"דצמ׳"
	],
	"field-second-narrow": "שנ׳",
	"field-month-relative+0": "החודש",
	"field-month-relative+1": "החודש הבא",
	"dateFormat-full": "EEEE, d בMMMM y",
	"field-era-narrow": "תקופה",
	"field-sat-short-relative+-1": "שבת שעברה",
	"field-week-short-relative+-1": "השבוע שעבר",
	"dateTimeFormat-long": "{1} בשעה {0}",
	"dateFormatItem-yM": "M.y",
	"field-sun-relative+-1": "ביום ראשון שעבר",
	"field-wed-short-relative+-1": "יום ד׳ שעבר",
	"field-weekdayOfMonth": "יום חול בחודש",
	"field-quarter-narrow-relative+0": "רבעון זה",
	"dateFormatItem-GyMMMEd": "E, d בMMM y G",
	"field-quarter-narrow-relative+1": "הרבעון הבא",
	"field-sat-short-relative+0": "שבת",
	"field-hour-narrow": "שע׳",
	"field-sat-short-relative+1": "שבת הבאה",
	"field-year-narrow-relative+0": "השנה",
	"field-year-narrow-relative+1": "השנה הבאה",
	"dateFormatItem-Gy": "y G",
	"field-zone-narrow": "אזור",
	"field-tue-relative+-1": "יום שלישי שעבר",
	"field-minute-short": "דק׳",
	"dateFormatItem-yw": "שבוע w בשנת Y",
	"dateFormatItem-Hm": "H:mm",
	"field-week-relative+0": "השבוע",
	"field-week-relative+1": "השבוע הבא",
	"dateFormatItem-MMM": "LLL",
	"field-sun-relative+0": "ביום ראשון הזה",
	"field-sun-relative+1": "ביום ראשון הבא",
	"field-sat-narrow-relative+-1": "שבת שעברה",
	"quarters-standAlone-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"dateFormatItem-MMMMW": "שבוע W בMMMM",
	"field-month-short-relative+-1": "החודש שעבר",
	"dateFormatItem-EHms": "E H:mm:ss",
	"dateFormatItem-MMMMd": "d בMMMM",
	"field-week": "שבוע",
	"field-day-narrow": "יום"
}
//end v1.x content
);